==> scipion-em-phenix-1.0.4.tar.gz: scipion-em-phenix-1.0.4/phenix/viewers/__init__.py <==
# **************************************************************************
# *
# * Authors:     Yunior C. Fonseca Reyna (cfonseca@cnb.csic.es)
# *
# * Unidad de  Bioinformatica of Centro Nacional de Biotecnologia , CSIC
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 2 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion@cnb.csic.es'
# *
# **************************************************************************

from viewer_emringer import PhenixProtRunEMRingerViewer
from viewer_molprobity import PhenixProtRunMolprobityViewer
from viewer_real_space_refine import PhenixProtRunRSRefineViewer
from viewer_refinement_base import PhenixProtRefinementBaseViewer
from viewer_superpose_pdbs import PhenixProtRunSuperposePDBsViewer
from viewer_validation_cryoem import PhenixProtRunValidationCryoEMViewer

==> scipion-em-phenix-3.0.1.tar.gz: scipion-em-phenix-3.0.1/phenix/viewers/__init__.py <==
# **************************************************************************
# *
# * Authors:     Yunior C. Fonseca Reyna (cfonseca@cnb.csic.es)
# *
# * Unidad de  Bioinformatica of Centro Nacional de Biotecnologia , CSIC
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 2 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion@cnb.csic.es'
# *
# **************************************************************************

from .viewer_emringer import PhenixProtRunEMRingerViewer
from .viewer_molprobity import PhenixProtRunMolprobityViewer
from .viewer_real_space_refine import PhenixProtRunRSRefineViewer
from .viewer_refinement_base import PhenixProtRefinementBaseViewer
from .viewer_superpose_pdbs import PhenixProtRunSuperposePDBsViewer
from .viewer_validation_cryoem import PhenixProtRunValidationCryoEMViewer
from .viewer_dock_in_map import PhenixProtRunDockInMapViewer
